<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Core\Base\Document;
use Elementor\Core\Base\Module as BaseModule;
use Elementor\Plugin;
use Elementor\Utils;
use Elementor\Core\DocumentTypes\PageBase as PageBase;
use Elementor\Modules\Library\Documents\Page as LibraryPageDocument;

if( !defined( 'ABSPATH' ) ) exit;

class Naturally_Customizing_Page_Settings {

    private static $instance = null;

    public static function get_instance() {
        if ( null == self::$instance ) {
            self::$instance = new Naturally_Customizing_Page_Settings();
        }
        return self::$instance;
    }

    public function __construct(){
        // custom option for elementor heading widget font size
        add_action( 'elementor/element/post/document_settings/before_section_end',[ $this,'naturally_add_custom_settings_to_page_settings'], 10);
        add_action( 'elementor/element/post/section_page_style/after_section_end',[ $this,'naturally_add_custom_settings_to_page_style_settings'], 10);
        add_action( 'elementor/element/post/section_page_style/after_section_end',[ $this,'naturally_add_custom_css_to_page_settings'], 10);
        //add_action( 'elementor/documents/register_controls',[ $this,'naturally_add_custom_settings_to_page_style_settings'], 10);
    }

    public function naturally_add_custom_settings_to_page_settings( $page )
    {

        if(isset($page) && $page->get_id() > ""){

            $nt_post_type   = false;
            $nt_post_type   = get_post_type($page->get_id());

            if ( $nt_post_type == 'page' || $nt_post_type == 'revision' ) {

                $page->add_control( 'naturally_elementor_hide_page_header',
                    [
                        'label'         => esc_html__( 'Hide Header', 'naturally' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Yes', 'naturally' ),
                        'label_off'     => esc_html__( 'No', 'naturally' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                        'condition'     => [ 'template'   => 'naturally-elementor-page.php' ]
                    ]
                );
                $page->add_control( 'naturally_elementor_page_header_type',
                    [
                        'label'         => esc_html__( 'Header Type', 'naturally' ),
                        'type'          => Controls_Manager::SELECT,
                        'default'       => '',
                        'options'       => [
                            ''              => esc_html__( 'Slect a type', 'naturally' ),
                            'default'       => esc_html__( 'Default', 'naturally' ),
                            'is-overlay'    => esc_html__( 'Transparent', 'naturally' ),
                        ],
                        'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                    ]
                );
                $page->add_control( 'naturally_elementor_page_header_menu',
                    [
                        'label'         => esc_html__( 'Header Menu', 'naturally' ),
                        'type'          => Controls_Manager::SELECT,
                        'default'       => '',
                        'options'       => $this->naturally_page_registered_nav_menus(),
                        'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                    ]
                );
                $page->add_control( 'naturally_elementor_hide_page_header_topbar',
                    [
                        'label'         => esc_html__( 'Hide Header Topbar', 'naturally' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Yes', 'naturally' ),
                        'label_off'     => esc_html__( 'No', 'naturally' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                        'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                    ]
                );
                $page->add_control( 'naturally_elementor_hide_page_footer',
                    [
                        'label'         => esc_html__( 'Hide Footer', 'naturally' ),
                        'type'          => Controls_Manager::SWITCHER,
                        'label_on'      => esc_html__( 'Yes', 'naturally' ),
                        'label_off'     => esc_html__( 'No', 'naturally' ),
                        'return_value'  => 'yes',
                        'default'       => 'no',
                        'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                    ]
                );

                if ( 'default' == naturally_settings( 'footer_type', 'default' ) ) {
                    $page->add_control( 'naturally_elementor_hide_page_footer_widget_area',
                        [
                            'label'         => esc_html__( 'Hide Footer Widgetize', 'naturally' ),
                            'type'          => Controls_Manager::SWITCHER,
                            'label_on'      => esc_html__( 'Yes', 'naturally' ),
                            'label_off'     => esc_html__( 'No', 'naturally' ),
                            'return_value'  => 'yes',
                            'default'       => 'no',
                            'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                        ]
                    );
                    $page->add_control( 'naturally_elementor_hide_page_footer_copyright',
                        [
                            'label'         => esc_html__( 'Hide Footer Copyright', 'naturally' ),
                            'type'          => Controls_Manager::SWITCHER,
                            'label_on'      => esc_html__( 'Yes', 'naturally' ),
                            'label_off'     => esc_html__( 'No', 'naturally' ),
                            'return_value'  => 'yes',
                            'default'       => 'no',
                            'condition'     => [ 'template' => 'naturally-elementor-page.php' ]
                        ]
                    );
                }
            }
        }
    }

    public function naturally_add_custom_settings_to_page_style_settings( $page )
    {
        if(isset($page) && $page->get_id() > ""){

            $nt_post_type = false;
            $nt_post_type = get_post_type($page->get_id());

            if ( $nt_post_type == 'page' || $nt_post_type == 'revision' ) {
                /***********************************************/
                /**************** STYLE OPTIONS ****************/
                /***********************************************/
                $page->start_controls_section( 'header_style_controls_section',
                    [
                        'label'        => esc_html__( 'Page Header Style', 'naturally' ),
                        'tab'          => Controls_Manager::TAB_STYLE,
                        'condition'    => [ 'naturally_elementor_hide_page_header!'   => 'yes' ]
                    ]
                );
                $page->add_control( 'header_background_heading',
                    [
                        'label'         => esc_html__( 'Background Style', 'naturally' ),
                        'type'          => Controls_Manager::HEADING
                    ]
                );
                $page->add_control( 'logo_brightness',
                    [
                        'label'         => esc_html__( 'Logo Brightness', 'naturally' ),
                        'type'          => Controls_Manager::SLIDER,
                        'range'         => [ '%'   => [ 'max' => 100 ] ],
                        'selectors'     => [ '{{WRAPPER}} .header .header_logo img' => '-webkit-filter: brightness({{SIZE}}); filter: brightness({{SIZE}});' ],
                        'separator'     => 'after'
                    ]
                );
                $page->add_responsive_control( 'header_padding',
                    [
                        'label'         => esc_html__( 'Padding', 'naturally' ),
                        'type'          => Controls_Manager::DIMENSIONS,
                        'size_units'    => [ 'px', 'em', '%' ],
                        'selectors'     => ['{{WRAPPER}} .header .header_container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;'],
                        'default'       => [
                            'top'          => '',
                            'right'        => '',
                            'bottom'       => '',
                            'left'         => '',
                        ],
                        'separator'     => 'after'
                    ]
                );
                $page->add_group_control(
                    Group_Control_Background::get_type(),
                    [
                        'name'          => 'header_background',
                        'label'         => esc_html__( 'Background', 'naturally' ),
                        'types'         => [ 'classic', 'gradient' ],
                        'selector'      => '{{WRAPPER}} .header',
                        'separator'     => 'before'
                    ]
                );

                $page->add_control( 'header_background_hr', [ 'type' => Controls_Manager::DIVIDER ] );

                $page->add_control( 'header_menu_heading',
                    [
                        'label'         => esc_html__( 'Menu Style', 'naturally' ),
                        'type'          => Controls_Manager::HEADING
                    ]
                );
                $page->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                        'name'          => 'header_menu_item_typo',
                        'label'         => esc_html__( 'Typography', 'naturally' ),
                        'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                        'selector'      => '{{WRAPPER}} .navbar-nav>li>a, {{WRAPPER}} .header_nav_sub a'
                    ]
                );
                $page->start_controls_tabs('header_menu_item_normal_tabs');
                $page->start_controls_tab( 'header_menu_item_normal_tab',
                    [ 'label'           => esc_html__( 'Normal', 'naturally' ) ]
                );
                $page->add_control( 'header_menu_item_normal_color',
                    [
                        'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['@media(min-width:1200px){ .header_nav > ul:not(.sub_menu) > li > a' => 'color: {{{VALUE}}};']
                    ]
                );
                $page->end_controls_tab();

                $page->start_controls_tab('header_menu_item_hover_tab',
                    [ 'label'           => esc_html__( 'Hover', 'naturally' ) ]
                );
                $page->add_control( 'header_menu_item_hover_color',
                    [
                        'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['@media(min-width:1200px){ .header_nav > ul:not(.sub_menu) > li > a:hover' => 'color: {{{VALUE}}};']
                    ]
                );
                $page->end_controls_tab();
                $page->end_controls_tabs();

                $page->end_controls_section();

                /* STICKY HEADER SETTINGS */
                if ( class_exists('Redux') && function_exists('naturally_settings') && '1' == naturally_settings('nav_sticky_visibility', '0') ) {

                    $page->start_controls_section( 'sticky_header_style_controls_section',
                        [
                            'label'         => esc_html__( 'Sticky Header Style', 'naturally' ),
                            'tab'           => Controls_Manager::TAB_STYLE,
                            'condition'     => [
                                'naturally_elementor_hide_page_header!'   => 'yes'
                            ]
                        ]
                    );
                    $page->add_control( 'sticky_header_background_heading',
                        [
                            'label'         => esc_html__( 'Background Style', 'naturally' ),
                            'type'          => Controls_Manager::HEADING
                        ]
                    );
                    $page->add_responsive_control( 'sticky_header_height',
                        [
                            'label'         => esc_html__( 'Height', 'naturally' ),
                            'type'          => Controls_Manager::SLIDER,
                            'range'         => [ 'px'   => [ 'max' => 500 ] ],
                            'selectors'     => [ '{{WRAPPER}} .header.is-sticky-active .header_container' => 'height: {{SIZE}}px!important;' ],
                            'separator'     => 'after'
                        ]
                    );
                    $page->add_responsive_control( 'sticky_header_padding',
                        [
                            'label'         => esc_html__( 'Padding', 'naturally' ),
                            'type'          => Controls_Manager::DIMENSIONS,
                            'size_units'    => [ 'px' ],
                            'selectors'     => ['{{WRAPPER}} .header.is-sticky-active .header_container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}!important;'],
                            'default'       => [
                                'top'          => '',
                                'right'        => '',
                                'bottom'       => '',
                                'left'         => '',
                            ],
                            'separator'     => 'after'
                        ]
                    );
                    $page->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name'          => 'sticky_header_background',
                            'label'         => esc_html__( 'Background', 'naturally' ),
                            'types'         => [ 'classic', 'gradient' ],
                            'selector'      => '{{WRAPPER}} .header.is-sticky.is-sticky-active',
                            'separator'     => 'before'
                        ]
                    );
                    $page->add_control( 'sticky_header_background_hr', [ 'type' => Controls_Manager::DIVIDER ] );
                    $page->add_control( 'sticky_header_menu_heading',
                        [
                            'label'         => esc_html__( 'Menu Style', 'naturally' ),
                            'type'          => Controls_Manager::HEADING
                        ]
                    );
                    $page->add_group_control(
                        Group_Control_Typography::get_type(),
                        [
                            'name'          => 'sticky_header_menu_item_typo',
                            'label'         => esc_html__( 'Typography', 'naturally' ),
                            'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                            'selector'      => '{{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav > ul > li > a, {{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav_sub a'
                        ]
                    );
                    $page->start_controls_tabs('sticky_header_menu_item_normal_tabs');
                    $page->start_controls_tab( 'sticky_header_menu_item_normal_tab',
                        [ 'label'           => esc_html__( 'Normal', 'naturally' ) ]
                    );
                    $page->add_control( 'sticky_header_menu_item_normal_color',
                        [
                            'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                            'type'          => Controls_Manager::COLOR,
                            'default'       => '',
                            'selectors'     => [ '{{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav > ul > li > a, {{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav_sub a' => 'color: {{VALUE}};' ]
                        ]
                    );
                    $page->end_controls_tab();

                    $page->start_controls_tab('sticky_header_menu_item_hover_tab',
                        [ 'label'           => esc_html__( 'Hover', 'naturally' ) ]
                    );
                    $page->add_control( 'sticky_header_menu_item_hover_color',
                        [
                            'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                            'type'          => Controls_Manager::COLOR,
                            'default'       => '',
                            'selectors'     => [ '{{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav > ul > li > a:hover, {{WRAPPER}} .header.is-sticky.is-sticky-active .header_nav_sub a:hover' => 'color: {{VALUE}};']
                        ]
                    );
                    $page->end_controls_tab();
                    $page->end_controls_tabs();
                    $page->end_controls_section();
                }
                /* END STICKY HEADER SETTINGS */

                /* MOBILE HEADER SETTINGS */
                $page->start_controls_section( 'header_mobile_style_controls_section',
                    [
                        'label'        => esc_html__( 'Page Header Mobile Style', 'naturally' ),
                        'tab'          => Controls_Manager::TAB_STYLE,
                        'condition'    => [
                            'naturally_elementor_hide_page_header!'   => 'yes',
                        ]
                    ]
                );

                $page->add_control( 'more_options',
                    [
                        'label'         => esc_html__( 'Mobile Menu Background', 'plugin-name' ),
                        'type'          => Controls_Manager::HEADING,
                        'separator'     => 'before',
                    ]
                );
                $page->add_group_control(
                    Group_Control_Background::get_type(),
                    [
                        'name'          => 'header_mobile_background',
                        'label'         => esc_html__( 'Mobile Menu Background', 'naturally' ),
                        'types'         => [ 'classic', 'gradient' ],
                        'selector'      => '{{WRAPPER}} .header_nav.is-active',
                    ]
                );
                $page->add_control( 'header_mobile_inner_background_hr', [ 'type' => Controls_Manager::DIVIDER ] );

                $page->add_control( 'header_mobile_menu_heading',
                    [
                        'label'         => esc_html__( 'Mobile Menu Style', 'naturally' ),
                        'type'          => Controls_Manager::HEADING
                    ]
                );
                $page->add_control( 'header_mobile_menu_bar_color',
                    [
                        'label'         => esc_html__( 'Menu Toggle Bar Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_toggle' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_bar_hvrcolor',
                    [
                        'label'         => esc_html__( 'Menu Toggle Bar Hover', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_toggle:hover' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_bar_brdcolor',
                    [
                        'label'         => esc_html__( 'Menu Toggle Bar Border Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_toggle' => 'border-color: {{VALUE}};']
                    ]
                );
                $page->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                        'name'          => 'header_mobile_menu_item_typo',
                        'label'         => esc_html__( 'Typography', 'naturally' ),
                        'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                        'selector'      => '{{WRAPPER}} .header_nav.is-active li > a'
                    ]
                );
                $page->start_controls_tabs('header_mobile_menu_normal_tabs');
                $page->start_controls_tab( 'header_mobile_menu_normal_tab',
                    [ 'label'           => esc_html__( 'Normal', 'naturally' ) ]
                );
                $page->add_control( 'header_mobile_menu_normal_color',
                    [
                        'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav.is-active li > a' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_item_normal_bgcolor',
                    [
                        'label'         => esc_html__( 'Menu Item Background Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav.is-active li > a' => 'background-color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_arrow_normal_color',
                    [
                        'label'         => esc_html__( 'Menu Arrow Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_arrow' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_arrow_normal_bgcolor',
                    [
                        'label'         => esc_html__( 'Menu Arrow Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_arrow' => 'background-color: {{VALUE}};']
                    ]
                );
                $page->end_controls_tab();

                $page->start_controls_tab('header_mobile_menu_hover_tab',
                    [ 'label'           => esc_html__( 'Hover', 'naturally' ) ]
                );
                $page->add_control( 'header_mobile_menu_hover_color',
                    [
                        'label'         => esc_html__( 'Menu Item Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav.is-active li > a:hover' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_item_hover_bgcolor',
                    [
                        'label'         => esc_html__( 'Menu Item Background Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav.is-active li > a:hover,{{WRAPPER}} .header_nav.is-active li.is-active > a' => 'background-color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_arrow_hover_color',
                    [
                        'label'         => esc_html__( 'Menu Arrow Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_arrow:hover' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_mobile_menu_arrow_hover_bgcolor',
                    [
                        'label'         => esc_html__( 'Menu Arrow Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header_nav_arrow:hover' => 'background-color: {{VALUE}};']
                    ]
                );
                $page->end_controls_tab();
                $page->end_controls_tabs();
                $page->end_controls_section();
                /* END MOBILE HEADER SETTINGS */

                /* HEADER MINICART SETTINGS */
                $page->start_controls_section( 'header_minicart_style_controls_section',
                    [
                        'label'        => esc_html__( 'Header Minicart Style', 'naturally' ),
                        'tab'          => Controls_Manager::TAB_STYLE,
                        'condition'    => [ 'naturally_elementor_hide_page_header!'   => 'yes' ]
                    ]
                );
                $page->start_controls_tabs('header_minicart_normal_tabs');
                $page->start_controls_tab( 'header_minicart_normal_tab',
                    [ 'label'           => esc_html__( 'Normal', 'naturally' ) ]
                );
                $page->add_control( 'header_minicart_normal_color',
                    [
                        'label'         => esc_html__( 'Button Text Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_cart .header_cart_label' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_minicart_normal_brdcolor',
                    [
                        'label'         => esc_html__( 'Button Border Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_cart .header_cart_label' => 'border-color: {{VALUE}};']
                    ]
                );
                $page->end_controls_tab();

                $page->start_controls_tab('header_minicart_hover_tab',
                    [ 'label'           => esc_html__( 'Hover', 'naturally' ) ]
                );
                $page->add_control( 'header_minicart_hover_color',
                    [
                        'label'         => esc_html__( 'Button Text Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_cart .header_cart_label:hover, {{WRAPPER}} .header .header_cart.is-active .header_cart_label' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_minicart_hover_hvrbrdcolor',
                    [
                        'label'         => esc_html__( 'Button Border Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_cart .header_cart_label, {{WRAPPER}} .header .header_cart.is-active .header_cart_label' => 'border-color: {{VALUE}};']
                    ]
                );
                $page->end_controls_tab();
                $page->end_controls_tabs();

                $page->end_controls_section();
                /* HEADER TOPBAR SETTINGS */

                /* HEADER TOPBAR SETTINGS */
                $page->start_controls_section( 'header_topbar_style_controls_section',
                    [
                        'label'        => esc_html__( 'Page Header Topbar Style', 'naturally' ),
                        'tab'          => Controls_Manager::TAB_STYLE,
                        'condition'    => [ 'naturally_elementor_hide_page_header!'   => 'yes' ]
                    ]
                );
                $page->add_control( 'header_topbar_item_color',
                    [
                        'label'         => esc_html__( 'Item Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_top,{{WRAPPER}} .header .header_top .header_menu_link' => 'color: {{VALUE}};']
                    ]
                );
                $page->add_control( 'header_topbar_item_hvrcolor',
                    [
                        'label'         => esc_html__( 'Item Link Hover Color', 'naturally' ),
                        'type'          => Controls_Manager::COLOR,
                        'default'       => '',
                        'selectors'     => ['{{WRAPPER}} .header .header_top .header_menu_link:hover,{{WRAPPER}} .header_lang:hover .header_lang_label' => 'color: {{VALUE}};']
                    ]
                );
                $page->end_controls_section();
                /* END HEADER TOPBAR SETTINGS */

                /* FOOTER SETTINGS */
                if ( class_exists('Redux') && function_exists('naturally_settings') && '1' == naturally_settings( 'footer_visibility', '1' )  && 'default' == naturally_settings( 'footer_type' )) {
                    $page->start_controls_section( 'page_footer_controls_section',
                        [
                            'label'        => esc_html__( 'Page Footer Style', 'naturally' ),
                            'tab'          => Controls_Manager::TAB_STYLE,
                            'condition'     => [ 'naturally_elementor_hide_page_footer!' => 'yes' ]
                        ]
                    );
                    $page->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name'          => 'page_footer_background',
                            'label'         => esc_html__( 'Background', 'naturally' ),
                            'types'         => [ 'classic', 'gradient' ],
                            'selector'      => '{{WRAPPER}} .footer'
                        ]
                    );
                    $page->add_responsive_control( 'page_footer_padding',
                        [
                            'label'         => esc_html__( 'Padding', 'naturally' ),
                            'type'          => Controls_Manager::DIMENSIONS,
                            'size_units'    => [ 'px', 'em', '%' ],
                            'selectors'     => [ '{{WRAPPER}} .footer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};' ],
                            'default'       => [
                                'top'          => '',
                                'right'        => '',
                                'bottom'       => '',
                                'left'         => ''
                            ],
                            'separator'     => 'before'
                        ]
                    );
                    $page->end_controls_section();
                }
                /* END FOOTER SETTINGS */
            }
        }
    }

    public function naturally_add_custom_css_to_page_settings( $page )
    {

        if(isset($page) && $page->get_id() > ""){

            $nt_post_type   = false;
            $nt_post_type   = get_post_type($page->get_id());

            if ( $nt_post_type == 'page' || $nt_post_type == 'revision' ) {

                $page->start_controls_section( 'header_custom_css_controls_section',
                    [
                        'label'        => esc_html__( 'Page Custom CSS', 'naturally' ),
                        'tab'          => Controls_Manager::TAB_STYLE,
                    ]
                );
                // Custom CSS
        		$page->add_control( 'naturally_page_custom_css',
        			[
        				'label' => __( 'Custom CSS', 'naturally' ),
        				'type' => Controls_Manager::CODE,
        				'language' => 'css',
        				'rows' => 20,
        			]
        		);
                $page->end_controls_section();
            }
        }
    }

    public function naturally_page_registered_nav_menus()
    {
        $menus = wp_get_nav_menus();
        $options = array();
        if ( ! empty( $menus ) && ! is_wp_error( $menus ) ) {
            foreach ( $menus as $menu ) {
                $options[ $menu->slug ] = $menu->name;
            }
        }
        return $options;
    }
}
Naturally_Customizing_Page_Settings::get_instance();
