<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Naturally_Woo_Page_Widget extends Widget_Base {
    use Naturally_Helper;
    public function get_name() {
        return 'naturally-woo-page';
    }
    public function get_title() {
        return 'Products Page (N)';
    }
    public function get_icon() {
        return 'eicon-columns';
    }
    public function get_categories() {
        return [ 'naturally-woo' ];
    }
    // Registering Controls
    protected function _register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'naturally' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        // Order
        $this->add_control( 'scenario',
            [
                'label' => esc_html__( 'Select Scenario', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'featured' => esc_html__( 'Featured', 'naturally' ),
                    'on-sale' => esc_html__( 'On Sale', 'naturally' ),
                    'best' => esc_html__( 'Best Selling', 'naturally' ),
                    'custom' => esc_html__( 'Specific Categories', 'naturally' ),
                ],
                'default' => 'newest'
            ]
        );
        // Category Filter Heading
        $this->add_control( 'category_filter_heading',
            [
                'label' => esc_html__( 'Category Filter', 'naturally' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        // Category Filter
        $this->add_control( 'category_filter',
            [
                'label' => esc_html__( 'Category', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->naturally_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        // Exclude Category
        $this->add_control( 'category_exclude_filter',
            [
                'label' => esc_html__( 'Exclude Category', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->naturally_cpt_taxonomies('product_cat'),
                'description' => 'Select Category(s) to Exclude',
            ]
        );
        // Post Filter Heading
        $this->add_control( 'post_filter_heading',
            [
                'label' => esc_html__( 'Post Filter', 'naturally' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        // Specific Post
        $this->add_control( 'post_filter',
            [
                'label' => esc_html__( 'Specific Post(s)', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->naturally_cpt_get_post_title('product'),
                'description' => 'Select Specific Post(s)',
                'condition' => [ 'scenario' => 'custom' ]
            ]
        );
        // Exclude Post
        $this->add_control( 'post_exclude_filter',
            [
                'label' => esc_html__( 'Exclude Post', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->naturally_cpt_get_post_title('product'),
                'description' => 'Select Post(s) to Exclude',
                'separator' => 'after',
            ]
        );
        // Other Filter Heading
        $this->add_control( 'post_other_heading',
            [
                'label' => esc_html__( 'Other Filter', 'naturally' ),
                'type' => Controls_Manager::HEADING
            ]
        );
        // Posts Per Page
        $this->add_control( 'post_per_page',
            [
                'label' => esc_html__( 'Posts Per Page', 'naturally' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 1000,
                'default' => 20
            ]
        );
        // Order
        $this->add_control( 'order',
            [
                'label' => esc_html__( 'Select Order', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__( 'Ascending', 'naturally' ),
                    'DESC' => esc_html__( 'Descending', 'naturally' )
                ],
                'default' => 'ASC'
            ]
        );
        $this->add_control( 'orderby',
            [
                'label' => esc_html__( 'Order By', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'id' => esc_html__( 'Post ID', 'naturally' ),
                    'menu_order' => esc_html__( 'Menu Order', 'naturally' ),
                    'rand' => esc_html__( 'Random', 'naturally' ),
                    'date' => esc_html__( 'Date', 'naturally' ),
                    'title' => esc_html__( 'Title', 'naturally' ),
                ],
                'default' => 'id',
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
        
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'products_on_off_settings',
            [
                'label' => esc_html__('General', 'naturally'),
            ]
        );
        $this->add_control( 'hidetitle',
            [
                'label' => esc_html__( 'Hide Title', 'naturally' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'naturally' ),
                'label_off' => esc_html__( 'No', 'naturally' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $this->add_control( 'title',
            [
                'label' => esc_html__( 'Title', 'naturally' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => get_the_title(),
                'label_block' => true,
                'condition' => [ 'hidetitle!' => 'yes' ],
            ]
        );
        $this->add_control( 'desc',
            [
                'label' => esc_html__( 'Description', 'naturally' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => '',
                'label_block' => true,
                'condition' => [ 'hidetitle!' => 'yes' ],
            ]
        );
        $this->add_control( 'hidebread',
            [
                'label' => esc_html__( 'Hide Breadcrumbs', 'naturally' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'naturally' ),
                'label_off' => esc_html__( 'No', 'naturally' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $this->add_control( 'hidecat',
            [
                'label' => esc_html__( 'Hide Category Block', 'naturally' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'naturally' ),
                'label_off' => esc_html__( 'No', 'naturally' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $this->add_control( 'cat_singular',
            [
                'label' => esc_html__( 'Category Text Singular', 'naturally' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Product',
                'pleaceholder' => esc_html__( 'Enter title here', 'naturally' ),
                'condition' => ['hidecat!' => 'yes']
            ]
        );
        $this->add_control( 'cat_plural',
            [
                'label' => esc_html__( 'Category Text Plural', 'naturally' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Products',
                'pleaceholder' => esc_html__( 'Enter title here', 'naturally' ),
                'condition' => ['hidecat!' => 'yes']
            ]
        );
        $this->add_control( 'hide_catalog',
            [
                'label' => esc_html__( 'Hide Filters-Catalog', 'naturally' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'naturally' ),
                'label_off' => esc_html__( 'No', 'naturally' ),
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $this->add_control( 'layout',
            [
                'label' => esc_html__( 'Layout', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'full-width',
                'options' => [
                    'left-sidebar' => esc_html__( 'Left Sidebar', 'naturally' ),
                    'right-sidebar' => esc_html__( 'Right Sidebar', 'naturally' ),
                    'full-width' => esc_html__( 'Full-width', 'naturally' ),
                ]
            ]
        );
        $this->add_control( 'type',
            [
                'label' => esc_html__( 'Products Type', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => esc_html__( 'Grid', 'naturally' ),
                    'list' => esc_html__( 'List', 'naturally' ),
                ]
            ]
        );
        $this->add_control('column',
            [
                'label' => esc_html__( 'Column', 'naturally' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 4,
                'default' => 3,
                'condition' => ['type' => 'grid']
            ]
        );

        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/
    }
    public function set_column() {
        $settings = $this->get_settings_for_display();
        return $settings['column'];
    }

    public function add_product_thumbs() {
		echo '<div class="shop-product_photo">
			<a href="'.get_permalink().'">';
                woocommerce_template_loop_product_thumbnail();
			echo '</a>
		</div>';
    }
    
    protected function render() {
        global $wp_query;
        $settings = $this->get_settings_for_display();
        
        add_filter('naturally_shop_column', array( $this, 'set_column' ));
        
        $aos = '';
        if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
            $aos = ' aos-init aos-animate';
	        remove_action( 'woocommerce_before_shop_loop_item_title', 'naturally_product_thumbs', 10 );
	        add_action( 'woocommerce_before_shop_loop_item_title', array( $this, 'add_product_thumbs' ), 10 );
        }
        
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => $settings['post_per_page'],
            'post__in'       => $settings['post_filter'],
            'post__not_in'   => $settings['post_exclude_filter'],
            'order'          => $settings['order'],
            'paged'          => $paged,
        );
            
        if ( 'featured' == $settings['scenario'] ) {
           $args['tax_query'] = array(
                array(
                    'taxonomy' => 'product_visibility',
                    'field'    => 'name',
                    'terms'    => 'featured',
                )
            );

        } elseif('on-sale' == $settings['scenario']) {
            
    		$args['meta_query'] = array(
	            'relation' => 'OR',
    	        array( // Simple products type
                    'key'       => '_sale_price',
                    'value'     => 0,
                    'compare'   => '>',
                    'type'      => 'numeric'
            	),
    	        array( // Variable products type
                    'key'       => '_min_variation_sale_price',
                    'value'     => 0,
                    'compare'   => '>',
                    'type'      => 'numeric'
    	        )
    		);
            
        } elseif('best' == $settings['scenario']) {

            $args['orderby'] = 'meta_value_num';
            $args['meta_key'] = 'total_sales';
            
        } else {
            
            $args['orderby'] = $settings['orderby'];
            
        }
        
        if ( $settings['category_filter'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy'  => 'product_cat',
                    'field'     => 'id',
                    'terms'     => $settings['category_filter'],
                    'operator'  => 'IN'
                )
            );
        }
        if ( $settings['category_exclude_filter'] ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy'  => 'product_cat',
                    'field'     => 'id',
                    'terms'     => $settings['category_exclude_filter'],
                    'operator'  => 'NOT IN'
                )
            );
        }
        
        $shop_display_mode = woocommerce_get_loop_display_mode();
        $shop_layout = $settings['layout'];
        $shop_column = 'full-width' != $shop_layout && is_active_sidebar( 'shop-page-sidebar' ) ? ' is-lg-8 is-xl-9' : '';
        
        if ( 'yes' != $settings['hidetitle'] ) {
            echo '<div class="section text-center">';
            	echo '<div class="container">';

            		echo '<div class="headline">';

        				if ( $settings['title'] ) {
            					echo '<h1 class="headline_title">'.$settings['title'].'</h1>';
        				} else {
            				    
            				if ( apply_filters( 'woocommerce_show_page_title', true ) ) {
            					echo '<h1 class="headline_title">';
            					    woocommerce_page_title();
            					echo '</h1>';
            				}
            			}
        				if ( $settings['desc'] ) {
            				echo '<p class="headline_summary">'.$settings['desc'].'</p>';
        				} else {
            				    
            				/**
                			 * Hook: woocommerce_archive_description.
                			 *
                			 * @hooked woocommerce_taxonomy_archive_description - 10
                			 * @hooked woocommerce_product_archive_description - 10
                			 */
                			do_action( 'woocommerce_archive_description' );
            			}
            		echo '</div>';
                		
                    if ( 'yes' != $settings['hidebread'] ) {
                		echo '<div class="breadcrumb">';
                			/**
                			 * Hook: woocommerce_before_main_content.
                			 *
                			 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
                			 * @hooked woocommerce_breadcrumb - 20
                			 * @hooked WC_Structured_Data::generate_website_data() - 30
                			 */
                			do_action( 'woocommerce_before_main_content' );
                
                		echo '</div>';
                    }
    
            	echo '</div>';
            echo '</div>';
        }
        
        echo '<div class="section woocommerce">';
        	echo '<div class="container">';
        		echo '<div class="grid">';
        			echo '<div class="grid_row is-40">';
        			
        				echo '<div class="grid_col is-12 mt-0 woo-message">';
							/**
							 * Hook: woocommerce_before_shop_loop.
							 *
							 * @hooked woocommerce_output_all_notices - 10
							 * @hooked woocommerce_result_count - 20
							 * @hooked woocommerce_catalog_ordering - 30
							 */
							do_action( 'woocommerce_before_shop_loop' );
        				echo '</div>';
        				
        				if ('yes' != $settings['hidecat']) {
        					echo '<div class="grid_col is-12 mb-0 '.esc_attr( $shop_display_mode ).'">';
        						echo '<div class="section section-shop-categories mt-0" data-ntr-shop-categories2>';
        							echo '<div class="slider-categories">';
        								echo '<div class="slick-slider">';
                                            $cats = get_terms('product_cat');
                                            foreach ($cats as $cat) {
                                                $imgid = get_term_meta($cat->term_id, 'thumbnail_id', true );
                                                $imgsrc = wp_get_attachment_url( $imgid );
                                                echo '<div class="slick-slide">';
                                                    echo '<a class="slider-categories_item" href="'.esc_url( get_term_link( $cat ) ).'">';
                                                        if ($imgsrc) {
                                                            echo '<img class="slider-categories_item_photo" src="'.$imgsrc.'" alt="'.$cat->name.'">';
                                                        }
                                                        if ($cat->name) {
                                                            echo '<span class="slider-categories_item_name">'.$cat->name.'</span>';
                                                        }
                                                        if ($cat->count > 0) {
                                                            echo '<span class="slider-categories_item_count">'.sprintf(_n('%d '.$settings['cat_singular'], '%d '.$settings['cat_plural'], $cat->count, 'naturally'),$cat->count) .'</span>';
                                                        }
                                                    echo '</a>';
                                                echo '</div>';
                                            }
        								echo '</div>';
        							echo '</div>';
        						echo '</div>';
        					echo '</div>';
        				}
        
        				if ( 'yes' != $settings['hide_catalog'] ) {
            				echo '<div class="grid_col is-12">';
            					echo '<div class="shop-header" data-ntr-shop-header>';
            						echo '<div class="shop-header_views">';
            							echo '<div class="shop-header_layout">';
            							    $gridactive = $settings['type'] == 'grid' ? ' is-active' : '';
            							    $listactive = $settings['type'] == 'list' ? ' is-active' : '';
            							    $column = $settings['column'] ? $settings['column'] : '3';
            								echo '<div class="shop-header_layout_item'.$gridactive.'" data-layout="grid-'.$column.'">';
            									echo '<span class="shop-header_layout_item_icon icon is-grid"></span>';
            									echo '<span class="shop-header_layout_item_text">'.esc_html__( 'Grid View', 'naturally' ).'</span>';
            								echo '</div>';
            								echo '<div class="shop-header_layout_item'.$listactive.'" data-layout="list">';
            									echo '<span class="shop-header_layout_item_icon icon is-list"></span>';
            									echo '<span class="shop-header_layout_item_text">'.esc_html__( 'List View', 'naturally' ).'</span>';
            								echo '</div>';
            							echo '</div>';
            							echo '<div class="shop-header_result">';
            								//woocommerce_result_count();
                                            echo '<p class="woocommerce-result-count">';
                                                $total = wp_count_posts('product')->publish;
                                            	if ( 1 === $total ) {
                                            		_e( 'Showing the single result', 'woocommerce' );
                                            	} elseif ( $total <= $settings['post_per_page'] || -1 === $settings['post_per_page'] ) {
                                            		/* translators: %d: total results */
                                            		printf( _n( 'Showing all %d result', 'Showing all %d results', $total, 'woocommerce' ), $total );
                                            	} else {
                                            		$first = ( $settings['post_per_page'] * wc_get_loop_prop( 'current_page' ) ) - $settings['post_per_page'] + 1;
                                            		$last  = min( $total, $settings['post_per_page'] * wc_get_loop_prop( 'current_page' ) );
                                            		/* translators: 1: first result 2: last result 3: total results */
                                            		printf( _nx( 'Showing %1$d&ndash;%2$d of %3$d result', 'Showing %1$d&ndash;%2$d of %3$d results', $total, 'with first and last result', 'woocommerce' ), $first, $last, $total );
                                            	}
                                            echo '</p>';
            							echo '</div>';
            						echo '</div>';
            						echo '<div class="shop-header_selects">';

                                		$show_default_orderby    = 'menu_order' === apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby', 'menu_order' ) );
                                		$catalog_orderby_options = apply_filters( 'woocommerce_catalog_orderby', 
                                		    array(
                                				'menu_order' => __( 'Default sorting', 'woocommerce' ),
                                				'popularity' => __( 'Sort by popularity', 'woocommerce' ),
                                				'rating'     => __( 'Sort by average rating', 'woocommerce' ),
                                				'date'       => __( 'Sort by latest', 'woocommerce' ),
                                				'price'      => __( 'Sort by price: low to high', 'woocommerce' ),
                                				'price-desc' => __( 'Sort by price: high to low', 'woocommerce' ),
                                			)
                                		);
                                		$default_orderby = wc_get_loop_prop( 'is_search' ) ? 'relevance' : apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby', '' ) );
                                		$orderby         = isset( $_GET['orderby'] ) ? wc_clean( wp_unslash( $_GET['orderby'] ) ) : $default_orderby;
                                        echo '<form class="woocommerce-ordering" method="get">';
                                        	echo '<select name="orderby" class="orderby" aria-label="'.esc_attr__( 'Shop order', 'woocommerce' ).'">';
                                        		foreach ( $catalog_orderby_options as $id => $name ) : 
                                        		    ob_start();
                                        		    selected( $orderby, $id );
                                        			echo '<option value="'.esc_attr( $id ).'" '.ob_get_clean() .'>'.esc_html( $name ).'</option>';
                                        		endforeach;
                                        	echo '</select>';
                                        	echo '<input type="hidden" name="paged" value="1" />';
                                        	wc_query_string_form_fields( null, array( 'orderby', 'submit', 'paged', 'product-page' ) );
                                        echo '</form>';
            						echo '</div>';
            					echo '</div>';
            				echo '</div>';
        				}
        
        				if ( 'left-sidebar' == $shop_layout && is_active_sidebar( 'shop-page-sidebar' ) ) {
        					echo '<div class="grid_col is-12 is-lg-4 is-xl-3'.$aos.'" data-aos="ntr-fade-up" data-aos-once="true">';
        						echo '<div class="shop-sidebar">';
        							echo '<div class="shop-sidebar_inner">';
        								dynamic_sidebar( 'shop-page-sidebar' );
        							echo '</div>';
        						echo '</div>';
        					echo '</div>';
        				}
        				
                        $type = $settings['type'] == 'grid' ? ' is-grid-'.$settings['column'] : ' is-grid-'.$settings['column'];
                        $type = $settings['type'] == 'list' ? ' is-list' : $type;
                        
        				echo '<div class="grid_col is-12'.$shop_column.$aos.'" data-aos="ntr-fade-up" data-aos-once="true">';
                            echo '<div class="shop-products'.$type.'">';
                            	echo '<div class="grid">';
                            		echo '<div class="grid_row is-40">';
            					        $orderby = 'menu_order';
                                        if ( isset( $_GET['orderby'] ) ) {
                                            $orderby = $_GET['orderby'];
                                        }
                                        if ($orderby == 'date') {
                                            $args['orderby'] = 'date';
                                            $args['order'] = 'desc';
                                        } elseif ($orderby == 'price-desc') {
                                            $args['orderby'] = 'meta_value_num';
                                            $args['order'] = 'desc';
                                            $args['meta_key'] = '_price';
                                        } elseif ($orderby == 'price') {
                                            $args['orderby'] = 'meta_value_num';
                                            $args['order'] = 'asc';
                                            $args['meta_key'] = '_price';
                                        } elseif ($orderby == 'popularity') {
                                            $args['orderby'] = 'meta_value_num';
                                            $args['order'] = 'asc';
                                            $args['meta_key'] = 'total_sales';
                                        } elseif ($orderby == 'rating') {
                                            $args['orderby'] = 'meta_value_num';
                                            $args['order'] = 'desc';
                                            $args['meta_key'] = '_wc_average_rating';
                                        }

                            		    $the_query = new \WP_Query( $args );
                                        if( $the_query->have_posts() ) {
                						    while ($the_query->have_posts()) {
                                                $the_query->the_post();
                
                								do_action( 'woocommerce_shop_loop' );
                								
                								wc_get_template_part( 'content', 'product' );
            
                						    }
                						    
                					    } else {
                
                						    do_action( 'woocommerce_no_products_found' );
                					    }
					                    wp_reset_postdata();
					                    
                        			echo '</div>';
                        		echo '</div>';
                        	echo '</div>';
                            if($the_query->max_num_pages>1) {
                    			echo '<div class="pagination woo-pagination">';
                    				echo '<div class="pagination_items">';
                                        echo paginate_links( apply_filters(
                                                'woocommerce_pagination_args', array( 
                                                    'base'      => esc_url( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) ), 
                                                    'format'    => '', 
                                                    'current'   => max( 1, get_query_var( 'paged' ) ), 
                                                    'total'     => $the_query->max_num_pages, 
                                                    'prev_text' => '<span class="icon is-prev"></span>', 
                                                    'next_text' => '<span class="icon is-next"></span>', 
                                                    'type'      => 'list', 
                                                    'end_size'  => 3, 
                                                    'mid_size'  => 3 
                                                )
                                            )       
                                        );
                    				echo '</div>';
                    			echo '</div>';
                            }
        				echo '</div>';
        				
        				if ( 'right-sidebar' == $shop_layout && is_active_sidebar( 'shop-page-sidebar' ) ) {
        					echo '<div class="grid_col is-12 is-lg-4 is-xl-3'.$aos.'" data-aos="ntr-fade-up" data-aos-once="true">';
        						echo '<div class="shop-sidebar">';
        							echo '<div class="shop-sidebar_inner">';
        								dynamic_sidebar( 'shop-page-sidebar' );
        							echo '</div>';
        						echo '</div>';
        					echo '</div>';
        				}

        			echo '</div>';
        		echo '</div>';
        	echo '</div>';
        echo '</div>';

        do_action( 'woocommerce_after_main_content' );

    }
}
