<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Naturally_Woo_Product_Item_Widget extends Widget_Base {
    use Naturally_Helper;
    public function get_name() {
        return 'naturally-woo-product-item';
    }
    public function get_title() {
        return 'Woo Product Item (N)';
    }
    public function get_icon() {
        return 'eicon-image-box';
    }
    public function get_categories() {
        return [ 'naturally-woo' ];
    }
    // Registering Controls
    protected function _register_controls() {
        /*****   START CONTROLS SECTION   ******/
        $this->start_controls_section( 'post_query_section',
            [
                'label' => esc_html__( 'Query', 'naturally' ),
                'tab' => Controls_Manager::TAB_CONTENT
            ]
        );
        $this->add_control( 'filter_by',
            [
                'label' => esc_html__( 'Show Product By', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'default' => 'title',
                'options' => [
                    'title' => esc_html__( 'Title', 'naturally' ),
                    'sku' => esc_html__( 'SKU', 'naturally' )
                ]
            ]
        );
        // Post Filter Heading
        $this->add_control( 'post_filter_heading',
            [
                'label' => esc_html__( 'Post Filter', 'naturally' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        // Specific Post
        $this->add_control( 'post_filter',
            [
                'label' => esc_html__( 'Specific Post(s)', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'options' => $this->naturally_cpt_get_post_title('product'),
                'description' => 'Select Specific Post(s)',
                'condition' => [ 'filter_by' => 'title' ]
            ]
        );
        // Specific Post
        $this->add_control( 'post_skus',
            [
                'label' => esc_html__( 'Specific SKU', 'naturally' ),
                'type' => Controls_Manager::SELECT2,
                'multiple' => false,
                'options' => $this->naturally_woo_get_skus(),
                'description' => 'Select Specific SKU',
                'condition' => [ 'filter_by' => 'sku' ]
            ]
        );
        $this->add_control( 'type',
            [
                'label' => esc_html__( 'Product Box Type', 'naturally' ),
                'type' => Controls_Manager::SELECT,
                'label_block' => 'true',
                'default' => '1',
                'options' => [
                    '1' => esc_html__( 'Default', 'naturally' ),
                    '2' => esc_html__( 'List Type', 'naturally' )
                ]
            ]
        );
        $this->end_controls_section();
        /*****   END CONTROLS SECTION   ******/

    }
    
    protected function render() {
        global $wp_query;
        $settings  = $this->get_settings_for_display();
        $elementid = $this->get_id();
        
        $args = array(
            'post_type'      => 'product',
            'posts_per_page' => 1,
        );
        
        if ( 'sku' == $settings['filter_by'] ) {
            
            if ( $settings['post_skus'] ) {
            
                $args['meta_query'] = [
                    [
                        'key'     => '_sku',
                        'value'   => $settings['post_skus'],
                        'compare' => '='
                    ]
                ];
            }
            
        } else {
            
            if ( $settings['post_filter'] ) {
                $args['post__in'] = array($settings['post_filter']);
            }
        }

        $the_query = new \WP_Query( $args );
        if( $the_query->have_posts() ) {
            echo '<div class="product-items woocommerce">';

                while ($the_query->have_posts()) {
                    $the_query->the_post();
                    global $product;

                    if ( '2' == $settings['type'] ) {
    
                        remove_action( 'woocommerce_after_shop_loop_item', 'naturally_product_price', 5 );
                        remove_action( 'woocommerce_after_shop_loop_item', 'naturally_before_product_buttons', 9 );
                        remove_action( 'woocommerce_after_shop_loop_item', 'naturally_after_product_buttons', 25 );
                        ob_start();
                        wc_product_class( 'shop-product2 hover-shadow', $product );
                        echo '<div '.ob_get_clean().'>';
                            naturally_product_badge();
                            echo '<div class="shop-product2_photo">';
                                echo '<a href="'.get_permalink().'">';
                                    if ( function_exists('naturally_aq_resize') ) { 
                                    
                                        $blankimg = get_template_directory_uri().'/images/blank.gif';
                                        $srcset1 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 400, 400, true, true, true );
                                        $srcset2 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 800, 800, true, true, true );
                                        $imagealt = esc_attr(get_post_meta(get_post_thumbnail_id(), '_wp_attachment_image_alt', true));
                                        echo '<span class="aspect-ratio is-1x1">';
                                        echo '<img class="aspect-ratio_object lazyload" 
                                        src="'.esc_url( $blankimg ).'" 
                                        data-srcset="'.esc_url( $srcset1 ).' 1x, '.esc_url( $srcset2 ).' 2x" 
                                        alt="'.esc_attr( $imagealt ).'">';
                                        
                                    echo '</span>';
                                    } else {
                                    
                                    woocommerce_template_loop_product_thumbnail();
                                    }
                                echo '</a>';
                            echo '</div>';
                            echo '<div class="shop-product2_body">';
                                echo '<div class="shop-product2_title">';
                                    echo '<a href="'.get_permalink().'">'.get_the_title().'</a>';
                                echo '</div>';
                                if( wc_review_ratings_enabled() && $product->get_average_rating() ){
                                    echo '<div class="shop-product2_rating">';
                                        echo '<div class="rating">';
                                            woocommerce_template_loop_rating();
                                        echo '</div>';
                                    echo '</div>';
                                }
                                if( $product->get_price_html() ){
                                    echo '<div class="shop-product2_prices">';
                                        woocommerce_template_loop_price();
                                    echo '</div>';
                                }
                            echo '</div>';
                            
                            echo '<div class="shop-product2_actions">';
                                do_action( 'woocommerce_after_shop_loop_item' );
                            echo '</div>';
                        echo '</div>';
                        
                    } else {
                        ob_start();
                        wc_product_class( 'shop-product hover-shadow', $product );
                        echo '<div '.ob_get_clean().'>';
                            naturally_product_badge();
                            echo '<div class="shop-product_photo">';
                                echo '<a href="'.get_permalink().'">';
                                    if ( function_exists('naturally_aq_resize') ) { 
                                        $blankimg = get_template_directory_uri().'/images/blank.gif';
                                        $srcset1 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 400, 400, true, true, true );
                                        $srcset2 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 800, 800, true, true, true );
                                        $imagealt = esc_attr(get_post_meta(get_post_thumbnail_id(), '_wp_attachment_image_alt', true));
                                        echo '<span class="aspect-ratio is-1x1">';
                                            echo '<img class="aspect-ratio_object lazyload" 
                                            src="'.esc_url( $blankimg ).'" 
                                            data-srcset="'.esc_url( $srcset1 ).' 1x, '.esc_url( $srcset2 ).' 2x" 
                                            alt="'.esc_attr( $imagealt ).'">';
                                            
                                        echo '</span>';
                                    } else {
                                    
                                        woocommerce_template_loop_product_thumbnail();
                                    }
                                echo '</a>';
                            echo '</div>';
                            
                            echo '<div class="shop-product_content">';
                                echo '<div class="shop-product_body">';
                                
                                    echo '<div class="shop-product_title">';
                                        echo '<a href="'.get_permalink().'">'.get_the_title().'</a>';
                                    echo '</div>';
                                    if( wc_review_ratings_enabled() && $product->get_average_rating() ){
                                        echo '<div class="shop-product_rating">';
                                            echo '<div class="rating">';
                                                woocommerce_template_loop_rating();
                                            echo '</div>';
                                        echo '</div>';
                                    }
                                echo '</div>';
                                
                                echo '<div class="shop-product_footer">';
                                    do_action( 'woocommerce_after_shop_loop_item' );
                                echo '</div>';
                                
                            echo '</div>';
                        echo '</div>';
                    }
                }

            echo '</div>';
        }
        wp_reset_postdata();
    }
}