<?php

/**
 *
 * @package WordPress
 * @subpackage naturally
 * @since Naturally 1.0
 *
**/


/*************************************************
## GOOGLE FONTS
*************************************************/

if (! function_exists('naturally_fonts_url')) {
    function naturally_fonts_url()
    {
        $fonts_url = '';

        $merriweather = _x('on', 'Merriweather font: on or off', 'naturally');

        if ('off' !== $merriweather ) {
            $font_families = array();

            if ('off' !== $merriweather) {
                $font_families[] = 'Merriweather:300,300i,400,400i,700,700i,900,900i';
            }

            $query_args = array(
                'family' => urlencode(implode('|', $font_families)),
                'subset' => urlencode('latin,latin-ext'),
            );

            $fonts_url = add_query_arg($query_args, "//fonts.googleapis.com/css");
        }

        return esc_url_raw( $fonts_url );
    }
}

/*************************************************
## STYLES AND SCRIPTS
*************************************************/

function naturally_theme_scripts()
{

    // theme inner pages files
    wp_enqueue_style( 'naturally-framework-style', get_template_directory_uri() . '/css/framework-style.css', false, '1.0' );


    // plugins
    wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/libs/jquery-ui/jquery-ui.min.css', false, '1.0' );
    wp_enqueue_style( 'jquery-magnific-popup', get_template_directory_uri() . '/libs/magnific/jquery.magnific-popup.css', false, '1.0' );
    wp_enqueue_style( 'slick', get_template_directory_uri() . '/libs/slick/slick.css', false, '1.0' );
    wp_enqueue_style( 'aos', get_template_directory_uri() . '/libs/aos/aos.css', false, '1.0' );
    wp_enqueue_style( 'nice-select', get_template_directory_uri() . '/libs/nice-select/nice-select.css', false, '1.0' );
    wp_enqueue_style( 'naturally-font-awesome', get_template_directory_uri() . '/libs/font-awesome/font-awesome.min.css', false, '1.0' );

    // naturally-main-style
    wp_enqueue_style( 'naturally-style', get_template_directory_uri() . '/css/style.css', false, '1.0' );
    // naturally-update-style
    wp_register_style( 'naturally-elementor', get_template_directory_uri() . '/css/elementor-custom.css', false, '1.0' );
    wp_enqueue_style( 'naturally-update', get_template_directory_uri() . '/css/update.css', false, '1.0' );

    // upload Google Webfonts
    wp_enqueue_style( 'naturally-fonts', naturally_fonts_url(), array(), null );


    // ## JS
    // theme inner page files

    wp_enqueue_script( 'jquery-ui', get_template_directory_uri() . '/libs/jquery-ui/jquery-ui.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jquery-magnific-popup', get_template_directory_uri() . '/libs/magnific/jquery.magnific-popup.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . '/libs/waypoints/jquery.waypoints.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jquery-countTo', get_template_directory_uri() . '/libs/countTo/jquery.countTo.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'slick', get_template_directory_uri() . '/libs/slick/slick.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'imagesloaded-pkgd', get_template_directory_uri() . '/libs/isotope/imagesloaded.pkgd.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'isotope-pkgd', get_template_directory_uri() . '/libs/isotope/isotope.pkgd.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'lazysizes', get_template_directory_uri() . '/libs/aos/lazysizes.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'aos', get_template_directory_uri() . '/libs/aos/aos.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jarallax', get_template_directory_uri() . '/libs/jarallax/jarallax.min.js', array('jquery'), '1.0', true );
    wp_enqueue_script( 'jquery-nice-select', get_template_directory_uri() . '/libs/nice-select/jquery.nice-select.min.js', array('jquery'), '1.0', true );

    wp_enqueue_script( 'naturally-main', get_template_directory_uri() . '/js/scripts.js', array('jquery'), '1.0', true );

    wp_enqueue_script( 'framework-settings', get_template_directory_uri() . '/js/framework-settings.js', array('jquery'), '1.0', true );

    if( 'masonry' == naturally_settings( 'index_type', 'default' ) ) {
        wp_enqueue_script( 'masonry' );
    }

    // browser hacks
    wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.min.js', array('jquery'), '1,0', false );
    wp_script_add_data( 'modernizr', 'conditional', 'lt IE 9');
    wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/respond.min.js', array('jquery'), '1.0', false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9');
    wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5shiv.min.js', array('jquery'), '1.0', false );
    wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

    // comment form reply
    if (is_singular()) {
        wp_enqueue_script('comment-reply');
    }

}
add_action('wp_enqueue_scripts', 'naturally_theme_scripts');


function naturally_resource_hints( $urls, $relation_type ) {

    if ( wp_style_is( 'naturally-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
        $urls[] = array(
            'href' => 'https://fonts.gstatic.com',
            'crossorigin',
        );
    }

    return $urls;
}
add_filter( 'wp_resource_hints', 'naturally_resource_hints', 10, 2 );


/*************************************************
## ADMIN STYLE AND SCRIPTS
*************************************************/


function naturally_admin_scripts()
{

    // Update CSS within in Admin
    wp_enqueue_script( 'naturally-custom-admin', get_template_directory_uri() . '/js/framework-admin.js', array('jquery','jquery-ui-sortable') );

}
add_action('admin_enqueue_scripts', 'naturally_admin_scripts');





// Template-functions
include get_template_directory() . '/inc/template-functions.php';

// Theme parts
include get_template_directory() . '/inc/template-parts/menu.php';
include get_template_directory() . '/inc/template-parts/post-formats.php';
include get_template_directory() . '/inc/template-parts/single-post-formats.php';
include get_template_directory() . '/inc/template-parts/paginations.php';
include get_template_directory() . '/inc/template-parts/comment-parts.php';
include get_template_directory() . '/inc/template-parts/small-parts.php';
include get_template_directory() . '/inc/template-parts/header-parts.php';
include get_template_directory() . '/inc/template-parts/footer-parts.php';
include get_template_directory() . '/inc/template-parts/page-hero.php';
include get_template_directory() . '/inc/template-parts/breadcrumbs.php';

// Theme dynamic css setting file
include get_template_directory() . '/inc/template-parts/custom-style.php';

// Theme post and page meta plugin for customization and more features
include get_template_directory() . '/inc/core/metaboxes.php';
// TGM plugin activation
include get_template_directory() . '/inc/core/class-tgm-plugin-activation.php';
// Redux theme options panel
include get_template_directory() . '/inc/core/theme-options/options.php';


// WooCommerce init
if ( class_exists( 'WooCommerce' ) ) {
    include get_template_directory() . '/woocommerce/init.php';
}

/*************************************************
## THEME SETUP
*************************************************/


if (! isset($content_width)) {
    $content_width = 960;
}

function naturally_theme_setup()
{

    /*
    * This theme styles the visual editor to resemble the theme style,
    * specifically font, colors, icons, and column width.
    */
    add_editor_style('custom-editor-style.css');

    // Add default posts and comments RSS feed links to head.
    add_theme_support('automatic-feed-links');
	add_image_size('naturally-square', 500, 500, true);
	add_image_size('naturally-single', 2400, 1200, true);
    /*
    * Enable support for Post Thumbnails on posts and pages.
    *
    * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
    */
    add_theme_support('post-thumbnails');
    add_theme_support( 'post-formats', array( 'gallery','link','image','quote','video','audio' ) );

    // theme supports
    add_theme_support('title-tag');
    add_theme_support('custom-background');
    add_theme_support('custom-header');
    add_theme_support('html5', array( 'search-form' ));


    // Make theme available for translation
    // Translations can be filed in the /languages/ directory
    load_theme_textdomain('naturally', get_template_directory() . '/languages');

    register_nav_menus(array(
        'header_menu' => esc_html__('Header Menu', 'naturally'),
        'footer_menu' => esc_html__('Footer Menu', 'naturally'),
    ));

}
add_action('after_setup_theme', 'naturally_theme_setup');


/*************************************************
## WIDGET COLUMNS
*************************************************/


function naturally_widgets_init()
{

    register_sidebar(array(
        'name' => esc_html__('Blog Sidebar', 'naturally'),
        'id' => 'sidebar-1',
        'description' => esc_html__('These widgets for the Blog page.', 'naturally'),
        'before_widget' => '<div class="nt-sidebar-inner-widget blog-sidebar_widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="nt-sidebar-inner-widget-title blog-sidebar_widget_title">',
        'after_title' => '</h4>'
    ));

    if (function_exists('get_field') && 'full-width' != get_field('naturally_page_layout')) {
        register_sidebar(array(
            'name' => esc_html__('Default Page Sidebar', 'naturally'),
            'id' => 'naturally-page-sidebar',
            'description' => esc_html__('These widgets for the Default Page pages.', 'naturally'),
            'before_widget' => '<div class="nt-sidebar-inner-widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="nt-sidebar-inner-widget-title widget-title blog-sidebar_widget_title">',
            'after_title' => '</h4>'
        ));
    }

    if (class_exists('Redux')) {
        if ('full-width' != naturally_settings( 'archive_layout', 'full-width' )) {
            register_sidebar(array(
                'name' => esc_html__('Archive Sidebar', 'naturally'),
                'id' => 'naturally-archive-sidebar',
                'description' => esc_html__('These widgets for the Archive pages.', 'naturally'),
                'before_widget' => '<div class="nt-sidebar-inner-widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h4 class="nt-sidebar-inner-widget-title widget-title blog-sidebar_widget_title">',
                'after_title' => '</h4>'
            ));
        }
        if ('full-width' != naturally_settings( 'search_layout', 'full-width' )) {
            register_sidebar(array(
                'name' => esc_html__('Search Sidebar', 'naturally'),
                'id' => 'naturally-search-sidebar',
                'description' => esc_html__('These widgets for the Search pages.', 'naturally'),
                'before_widget' => '<div class="nt-sidebar-inner-widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h4 class="nt-sidebar-inner-widget-title widget-title blog-sidebar_widget_title">',
                'after_title' => '</h4>'
            ));
        }
        if ('full-width' != naturally_settings( 'single_layout', 'full-width' )) {
            register_sidebar(array(
                'name' => esc_html__('Blog Single Sidebar', 'naturally'),
                'id' => 'naturally-single-sidebar',
                'description' => esc_html__('These widgets for the Blog single page.', 'naturally'),
                'before_widget' => '<div class="nt-sidebar-inner-widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h4 class="nt-sidebar-inner-widget-title widget-title blog-sidebar_widget_title">',
                'after_title' => '</h4>'
            ));
        }
        if ('1' == naturally_settings( 'footer_visibility', '1' ) && '1' == naturally_settings( 'footer_widgetize_visibility', '0' )) {
            register_sidebar(array(
                'name' => esc_html__('Footer Widget Area', 'naturally'),
                'id' => 'footer-widget-area',
                'description' => esc_html__('These widgets for the footer top section.', 'naturally'),
                'before_widget' => '',
                'after_widget' => '',
                'before_title' => '<h4 class="nt-footer-widget-title nt-sidebar-inner-widget-title blog-sidebar_widget_title">',
                'after_title' => '</h4>'
            ));
        }

    } // end if redux exists
} // end naturally_widgets_init
add_action('widgets_init', 'naturally_widgets_init');


/*************************************************
## INCLUDE THE TGM_PLUGIN_ACTIVATION CLASS.
*************************************************/


function naturally_register_required_plugins()
{

    $plugins = array(

        array(
            'name' => esc_html__('Contact Form 7', "naturally"),
            'slug' => 'contact-form-7'
        ),
        array(
            'name' => esc_html__('WooCommerce', "naturally"),
            'slug' => 'woocommerce'
        ),
        array(
            'name' => esc_html__('YITH WooCommerce Compare', "naturally"),
            'slug' => 'yith-woocommerce-compare'
        ),
        array(
            'name' => esc_html__('YITH WooCommerce Wishlist', "naturally"),
            'slug' => 'yith-woocommerce-wishlist'
        ),
        array(
            'name' => esc_html__('YITH WooCommerce Quick View', "naturally"),
            'slug' => 'yith-woocommerce-quick-view'
        ),
        array(
            'name' => esc_html__('Theme Options Panel', "naturally"),
            'slug' => 'redux-framework',
            'required' => true
        ),
        array(
            'name' => esc_html__('Elementor', "naturally"),
            'slug' => 'elementor',
            'required' => true
        ),
        array(
            'name' => esc_html__('Advanced Custom Fields - ACF', "naturally"),
            'slug' => 'advanced-custom-fields',
            'required' => true
        ),
        array(
            'name' => esc_html__('Envato Auto Update Theme', "naturally"),
            'slug' => 'envato-market',
            'source' => 'https://ninetheme.com/documentation/plugins/envato-market.zip',
            'required' => false
        ),
        array(
            'name' => esc_html__('Revolution Slider', "naturally"),
            'slug' => 'revslider',
            'source' => 'https://ninetheme.com/documentation/plugins/revslider.zip',
            'required' => false
        ),
        array(
            'name' => esc_html__('Naturally Elementor Addons', "naturally"),
            'slug' => 'naturally-elementor-addons',
            'source' => get_template_directory() . '/plugins/naturally-elementor-addons.zip',
            'required' => true,
            'version' => '1.0.2'
        )
        // end plugins list

    );

    $config = array(
        'id' => 'tgmpa',
        'default_path' => '',
        'menu' => 'tgmpa-install-plugins',
        'has_notices' => true,
        'dismissable' => true,
        'dismiss_msg' => '',
        'is_automatic' => true,
        'message' => '',
    );

    tgmpa($plugins, $config);

}
add_action('tgmpa_register', 'naturally_register_required_plugins');


/*************************************************
## ONE CLICK DEMO IMPORT
*************************************************/


/*************************************************
## THEME SETUP WIZARD
    https://github.com/richtabor/MerlinWP
*************************************************/

require_once get_parent_theme_file_path( '/inc/core/merlin/vendor/autoload.php' );
require_once get_parent_theme_file_path( '/inc/core/merlin/class-merlin.php' );
require_once get_parent_theme_file_path( '/inc/core/demo-wizard-config.php' );

function naturally_merlin_local_import_files() {
    return array(
        array(
            'import_file_name'              => esc_html__( 'Demo Import','naturally' ),
            // XML data
            'local_import_file'             => get_parent_theme_file_path( 'inc/core/merlin/demodata/data.xml' ),
            // Widget data
            'local_import_widget_file'      => get_parent_theme_file_path( 'inc/core/merlin/demodata/widgets.wie' ),
            // Theme options
            'local_import_redux'            => array(
                array(
                    'file_path'    => trailingslashit( get_template_directory() ). 'inc/core/merlin/demodata/redux.json',
                    'option_name' => 'naturally'
                )
            )
        )
    );
}
add_filter( 'merlin_import_files', 'naturally_merlin_local_import_files' );


/**
 * Execute custom code after the whole import has finished.
 */
function naturally_merlin_after_import_setup() {
    // Assign menus to their locations.
    $primary = get_term_by( 'name', 'Header Menu', 'nav_menu' );
    $footer = get_term_by( 'name', 'Footer Menu', 'nav_menu' );

    set_theme_mod(
        'nav_menu_locations', array(
            'header_menu' => $primary->term_id,
            'footer_menu' => $footer->term_id,
        )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );
    $blog_page_id  = get_page_by_title( 'Blog' );

    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
    update_option( 'page_for_posts', $blog_page_id->ID );

    if ( did_action( 'elementor/loaded' ) ) {
        // disable some default elementor global settings after setup theme
        update_option( 'elementor_disable_color_schemes', 'yes' );
        update_option( 'elementor_disable_typography_schemes', 'yes' );
        update_option( 'elementor_global_image_lightbox', 'yes' );
    }

    if ( defined( 'YITH_WCWL' ) ) {
       update_option( 'yith_wcwl_show_on_loop', 'yes' );
       update_option( 'yith_woocompare_compare_button_in_products_list', 'yes' );
   }

}
add_action( 'merlin_after_all_import', 'naturally_merlin_after_import_setup' );


add_action( 'admin_init', function() {
	if ( did_action( 'elementor/loaded' ) ) {
		remove_action( 'admin_init', [ \Elementor\Plugin::$instance->admin, 'maybe_redirect_to_getting_started' ] );
	}
}, 1 );

add_filter( 'woocommerce_prevent_automatic_wizard_redirect', '__return_true' );
