<?php

/**
 * Custom template parts for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package naturally
*/


/*************************************************
##  LOGO
*************************************************/

if (! function_exists('naturally_logo')) {
    function naturally_logo()
    {
        $logo = naturally_settings('logo_type', 'sitename');

        if ('0' != naturally_settings('logo_visibility', '1')) { ?>

            <a href="<?php echo esc_url(home_url('/')); ?>" id="nt-logo" class="header_logo logo-type-<?php echo esc_attr($logo); ?>">

            <?php if ('img' == $logo && '' != naturally_settings('img_logo')) { ?>

                <img src="<?php echo esc_url(naturally_settings('img_logo')['url']); ?>" alt="<?php echo esc_attr(get_bloginfo('name')); ?>" />

            <?php } elseif ('sitename' == $logo ) {?>

                <span class="headline_title"><?php bloginfo( 'name' ); ?></span>

            <?php } elseif ('customtext' == $logo) { ?>

                <span class="headline_title"><?php echo naturally_settings('text_logo'); ?></span>

            <?php } else { ?>

                <span class="headline_title"> <?php bloginfo( 'name' );?> </span>

            <?php } ?>
            </a>
            <?php
        }
    }
}


/*************************************************
##  HEADER NAVIGATION
*************************************************/

if (! function_exists('naturally_main_header')) {
    add_action('naturally_header_action', 'naturally_main_header', 10);
    function naturally_main_header()
    {
        $nav_visibility = naturally_settings( 'nav_visibility', '1' );
        $nav_page_visibility = naturally_page_settings( 'hide_page_header', '1' );
        $nav_visibility = is_page() ? $nav_page_visibility : $nav_visibility;

        $page_header_menu = naturally_page_settings( 'page_header_menu' );
        $page_header_menu = is_page() ? $page_header_menu : '';

        $header_type = naturally_settings( 'nav_type', 'default' );
        $page_header_type = naturally_page_settings( 'page_header_type', 'default' );
        $header_type = is_page() ? $page_header_type : $header_type;

        $header_topbar = naturally_settings( 'header_topbar_visibility', '0' );
        $page_header_topbar = naturally_page_settings( 'hide_page_header_topbar', '1' );
        $header_topbar = is_page() ? $page_header_topbar : $header_topbar;


        $header_margin = '0' == $header_topbar ? ' mt-0' : '';
        $header_defbg = get_template_directory_uri().'/images/bg-nav.jpg';
        $header_string = $header_type;
        $header_class  = [
            '1' == naturally_settings('nav_sticky_visibility', '0') ? 'is-sticky' : '',
            apply_filters( 'naturally_header_string', $header_string )
        ];

        if ('0' != $nav_visibility ) { ?>

            <div class="naturally-main-header header<?php echo esc_attr(implode(' ',$header_class)); ?>" data-ntr-header>
        		<div class="header_holder"></div>
        		<div class="header_container">
                    <?php if ( '0' != naturally_settings('header_search_visibility', '1') && '0' != $header_topbar ) { ?>
                        <?php echo naturally_header_search_form(); ?>
                    <?php } ?>
        			<div class="container">

                        <?php if ( '0' != $header_topbar ) { ?>
            				<div class="naturally_header_topbar header_top">

                                <?php if ( '' != naturally_settings('header_topbar_phone') ) { ?>
                					<div class="header_phone">
                						<span class="header_phone_icon icon is-support"></span>
                						<span class="header_phone_text"><?php echo naturally_settings('header_topbar_phone'); ?></span>
                					</div>
                                <?php } ?>

            					<div class="header_menu">

                                    <?php if ( '0' != naturally_settings('header_search_visibility', '0')) { ?>
                						<div class="header_menu_item">
                							<a class="header_menu_link header_search_open" href="#">
                								<span class="header_menu_link_icon icon is-search"></span>
                								<span class="header_menu_link_text"><?php echo esc_html_e('Search', 'naturally'); ?></span>
                							</a>
                						</div>
                                    <?php } ?>

                                    <?php do_action( 'naturally_header_woo_myaccount_action' ); ?>

            					</div>
                                <?php naturally_header_lang(); ?>
            				</div>
                        <?php } ?>

        				<div class="header_bottom<?php echo esc_attr($header_margin); ?>">

                            <?php naturally_logo(); ?>

        					<nav class="header_nav lg-bg-none" data-ntr-background="<?php echo naturally_settings('header_mob_bg_img', $header_defbg); ?>">
        						<a class="header_nav_close" href="#">
        							<span class="header_nav_close_text"><?php echo esc_html_e('Close', 'naturally'); ?></span>
        							<span class="header_nav_close_icon icon is-close"></span>
        						</a>
        						<ul>
                                    <?php
                                    //if ( has_nav_menu( 'header_menu' ) ) {
                                        wp_nav_menu(
                                            array(
                                                'menu' => $page_header_menu,
                                                'theme_location' => 'header_menu',
                                                'container' => '', // menu wrapper element
                                                'container_class' => '',
                                                'container_id' => '', // default: none
                                                'menu_class' => '', // ul class
                                                'menu_id' => '', // ul id
                                                'items_wrap' => '%3$s',
                                                'before' => '', // before <a>
                                                'after' => '', // after <a>
                                                'link_before' => '', // inside <a>, before text
                                                'link_after' => '', // inside <a>, after text
                                                'depth' => 4, // '0' to display all depths
                                                'echo' => true,
                                                'fallback_cb' => 'Naturally_Wp_Bootstrap_Navwalker::fallback',
                                                'walker' => new Naturally_Wp_Bootstrap_Navwalker()
                                            )
                                        );
                                    //}
                                    ?>
        						</ul>
        					</nav>

        					<div class="header_nav_toggle"><span class="icon is-menu"></span></div>

                            <?php
                            if ( '0' != naturally_settings('header_minicart_visibility', '1') && class_exists( 'WooCommerce' ) ) {
                                do_action( 'naturally_header_mini_cart_action');
                            }
                            ?>

        				</div>
        			</div>
        		</div>
        	</div>
            <?php
        }
    }
}


/*************************************************
##  HEADER LANGUAGE
*************************************************/

if (! function_exists('naturally_header_lang')) {
    function naturally_header_lang()
    {
        if ('0' != naturally_settings('nav_lang_visibility', '0')) { ?>
            <div class="header_lang">
                <div class="header_lang_label">
                    <span class="header_lang_label_icon icon is-internet"></span>
                    <?php if (function_exists('pll_the_languages')) : ?>
                        <span class="header_lang_label_text"><?php echo pll_current_language('name') ?></span>
                        <div class="header_lang_list polylang">
                            <ul class="header_lang_items">
                                <?php
                                pll_the_languages(
                                    array(
                                        'show_flags'=>1,
                                        'show_names'=>1,
                                        'dropdown'=>0,
                                        'raw'=>0,
                                        'hide_current'=>1,
                                        'display_names_as'=>'name'
                                    )
                                );
                                ?>
                            </ul>
                        </div>
                    <?php else : ?>
                        <span class="header_lang_label_text"><?php echo naturally_settings('header_first_lang_item', 'English');; ?></span>
                        <?php
                        $langs = naturally_settings('header_lang');
                        if(is_array($langs) && !empty($langs)) : ?>
                            <div class="header_lang_list">
                                <ul class="header_lang_items">
                                    <?php for ($i=0; $i < (count($langs)); $i++) {

                                        $name = $langs[$i] ? $langs[$i] : '';
                                        $flag = $langs[$i+1] ? $langs[$i+1] : '#';
                                        $url = $langs[$i+2] ? $langs[$i+2] : '#';
                                        if($name){ ?>
                                            <li class="header_lang_item">
                                                <a class="header_lang_link" href="<?php echo esc_url($url); ?>">
                                                    <img class="header_lang_link_flag" src="<?php echo esc_url($flag); ?>" alt="<?php echo esc_attr($name); ?>">
                                                    <span class="header_lang_link_text"><?php echo esc_html($name); ?></span>
                                                </a>
                                            </li>
                                        <?php
                                        }
                                        $i = $i+2;
                                    } ?>
                                </ul>
                            </div>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
            </div>
            <?php
        }
    }
}
