<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( class_exists( 'WooCommerce' ) ) {


	/*************************************************
	## ADD CUSTOM CSS FOR WOOCOMMERCE
	*************************************************/

	if ( !function_exists( 'naturally_woo_scripts' ) ) {
		function naturally_woo_scripts()
		{
			wp_enqueue_style( 'naturally-woo-general', get_template_directory_uri() . '/woocommerce/woo-general.css',false, '1.0' );
			wp_enqueue_style( 'naturally-woo-single', get_template_directory_uri() . '/woocommerce/woo-single.css',false, '1.0' );
			wp_enqueue_style( 'naturally-woo-update', get_template_directory_uri() . '/woocommerce/woo-update.css',false, '1.0' );
			wp_enqueue_script( 'naturally-woo-custom', get_template_directory_uri() . '/woocommerce/woo-custom.js', array('jquery'), '1.0', true );
		}
		add_action( 'wp_enqueue_scripts', 'naturally_woo_scripts' );
	}

	// remove woocommerce css on archive page


	/*************************************************
	## ADD THEME SUPPORT FOR WOOCOMMERCE
	*************************************************/
	if ( !function_exists( 'naturally_woo_theme_setup' ) ) {
		function naturally_woo_theme_setup() {

			add_theme_support( 'woocommerce'  );
			add_theme_support( 'woocommerce', array(
		        'thumbnail_image_width' => 450,
		        'single_image_width' => 980,
		    ) );
		    add_theme_support( 'wc-product-gallery-zoom' );
		    add_theme_support( 'wc-product-gallery-lightbox' );
		    add_theme_support( 'wc-product-gallery-slider' );
		}
		add_action( 'after_setup_theme', 'naturally_woo_theme_setup' );
	}


	/*********************************************************
	## WOOCOMMERCE HOOKS
	**********************************************************/
	// Shop page hooks
	remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
	remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
	remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
	remove_action( 'woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10 );

	// romove product related
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	// Product page remove link open and link close
	remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );

	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
	add_action( 'woocommerce_before_shop_loop_item_title', 'naturally_product_thumbs', 10 );

    // Single page button actions
    add_action( 'woocommerce_single_product_summary', 'naturally_single_button_actions', 35 );
    function naturally_single_button_actions(){
        if ( defined( 'YITH_WCWL' ) ) {

        echo'<div class="shop-product_actions btns"></div>';
    }
    }

	if ( ! function_exists( 'naturally_product_thumbs' ) ) {
		function naturally_product_thumbs()
		{
            global $product;
		?>
			<div class="shop-product_photo">
				<a href="<?php echo get_permalink();?>">
                   <?php if ( function_exists('naturally_aq_resize') ) {

                        $blankimg = get_template_directory_uri().'/images/blank.gif';
                        $srcset1 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 400, 400, true, true, true );
                        $srcset2 = naturally_aq_resize( wp_get_attachment_url( $product->get_image_id() ), 800, 800, true, true, true );
                        $imagealt = esc_attr(get_post_meta(get_post_thumbnail_id(), '_wp_attachment_image_alt', true)); ?>
    					<span class="aspect-ratio is-1x1">
    					<img class="aspect-ratio_object lazyload"
    					src="<?php echo esc_url( $blankimg );?>"
    					data-srcset="<?php echo esc_url( $srcset1 ); ?> 1x, <?php echo esc_url( $srcset2 ); ?> 2x"
    					alt="<?php echo esc_attr( $imagealt ); ?>">
    					</span>
                    <?php } else {

                        woocommerce_template_loop_product_thumbnail();
                    } ?>
				</a>
			</div>
		<?php
		}
	}


	remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
	add_action( 'woocommerce_after_shop_loop_item_title', 'naturally_product_title', 10 );

	if ( ! function_exists( 'naturally_product_title' ) ) {
		function naturally_product_title(){ ?>
			<div class="shop-product_title">
				<a href="<?php echo get_permalink();?>">
					<?php the_title();?>
				</a>
			</div>
		<?php
		}
	}

	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
	add_action( 'woocommerce_after_shop_loop_item_title', 'naturally_product_rating', 10 );

	if ( ! function_exists( 'naturally_product_rating' ) ) {
		function naturally_product_rating()
		{
			global $product;
			if( $product->get_average_rating() ){
			?>
				<div class="shop-product_rating">
					<div class="rating">
						<?php woocommerce_template_loop_rating();?>
					</div>
				</div>
			<?php
			}
		}
	}

	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
	add_action( 'woocommerce_after_shop_loop_item', 'naturally_before_product_buttons', 9 );
	add_action( 'woocommerce_after_shop_loop_item', 'naturally_after_product_buttons', 25 );
	add_action( 'woocommerce_after_shop_loop_item', 'naturally_product_price', 5 );

	if ( ! function_exists( 'naturally_product_price' ) ) {
		function naturally_product_price()
		{
			global $product;
			if( $product->get_price_html() ){
			?>
				<div class="shop-product_prices">
					<?php woocommerce_template_loop_price();?>
				</div>
			<?php } ?>

			<?php
		}
	}
	if ( ! function_exists( 'naturally_before_product_buttons' ) ) {
		function naturally_before_product_buttons()
		{ ?>
			<div class="shop-product_actions">
			<?php
		}
	}
	if ( ! function_exists( 'naturally_after_product_buttons' ) ) {
		function naturally_after_product_buttons()
		{ ?>
			</div>
			<?php
		}
	}
	add_action( 'woocommerce_after_shop_loop_item_title', 'naturally_product_excerpt', 15 );
	if ( ! function_exists( 'naturally_product_excerpt' ) ) {
		function naturally_product_excerpt()
		{ ?>
			<div class="shop-product_description">
				<?php the_excerpt();?>
			</div>
			<?php
		}
	}

	add_action('naturally_before_shop_orderby_action','naturally_before_shop_orderby',10);
	if ( ! function_exists( 'naturally_before_shop_orderby' ) ) {
		function naturally_before_shop_orderby()
		{
			if ( !is_shop() && !is_product_category() ) { ?>
				<div class="shop-header-select">
					<div class="grid">
						<div class="grid_row mb-40">
							<div class="grid_col is-12">
								<div class="shop-header">
									<div class="shop-header_selects header_orderby">
			<?php
			}
		}
	}

	add_action('naturally_after_shop_orderby_action','naturally_after_shop_orderby',10);
	if ( ! function_exists( 'naturally_after_shop_orderby' ) ) {
		function naturally_after_shop_orderby()
		{
			if ( !is_shop() && !is_product_category() ) { ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php
			}
		}
	}

	remove_action( 'woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10 );
	add_action( 'woocommerce_shop_loop_subcategory_title', 'naturally_shop_loop_subcategory_title', 10 );
	if(!function_exists('naturally_shop_loop_subcategory_title')){
		function naturally_shop_loop_subcategory_title($category)
		{ ?>
			<?php if ($category->name) { ?>
				<span class="slider-categories_item_name"><?php echo esc_html( $category->name );?></span>
			<?php } ?>
			<?php if ( $category->count > 0 ) { ?>
				<span class="slider-categories_item_count"><?php echo sprintf(_n('%d Product', '%d Products', $category->count, 'naturally'),$category->count); ?></span>
			<?php } ?>
		<?php
		}
	}


	/*********************************************************
	## 1. CUSTOM BADGE LABEL
	**********************************************************/
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
	add_action( 'woocommerce_before_shop_loop_item_title', 'naturally_product_badge', 10 );
	remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );
	add_action( 'woocommerce_before_single_product_summary', 'naturally_product_badge', 10 );

	if ( ! function_exists( 'naturally_product_badge' ) ) {

		function naturally_product_badge()
		{
			global $product;
			$badge = get_post_meta( $product->get_id(), 'naturally_badge', true );
			$badge_color = get_post_meta( $product->get_id(), 'naturally_badge_color', true );
			$badge_custom = get_post_meta( $product->get_id(), 'naturally_custom_badge', true );
			$badge_color = $badge_color ? $badge_color : 'is-green-light';
			$title = '';
			switch ($badge) {
				case 'new':
					$title = esc_html__('New','naturally');
					break;
				case 'hot':
					$title = esc_html__('Hot','naturally');
					break;
				case 'best':
					$title = esc_html__('Best','naturally');
					break;
				case 'featured':
					$title = esc_html__('Featured','naturally');
					break;
				case 'free':
					$title = esc_html__('Free','naturally');
					break;
				case 'custom':
					$title = $badge_custom;
					break;
				default:
					$title = '';
					break;
			}
			if ( '' != $title ) {
				echo '<div class="shop-product_labels"><span class="label '.esc_attr($badge_color).'">'.esc_html($title).'</span></div>';
			} else {
				if( $product->is_on_sale()){
					echo '<div class="shop-product_labels"><span class="label '.esc_attr($badge_color).'">'.esc_html__( 'Sale!', 'naturally' ).'</span></div>';
				}
			}
		}
	}

    /**
* @snippet Move & Change Number of Cross-Sells @ WooCommerce Cart
* @how-to Get CustomizeWoo.com FREE
* @sourcecode https://businessbloomer.com/?p=20449
* @author Rodolfo Melogli
* @testedwith WooCommerce 2.6.2
*/


// ---------------------------------------------
// Remove Cross Sells From Default Position

remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );


// ---------------------------------------------
// Add them back UNDER the Cart Table

add_action( 'woocommerce_after_cart', 'woocommerce_cross_sell_display' );



	/*********************************************************
	## 1. ADD NEW CHECKBOX TO PRODUCT EDIT PAGE (GENERAL TAB)
	**********************************************************/

	if ( ! function_exists( 'naturally_add_badge_checkbox_to_products' ) ) {

		add_action( 'woocommerce_product_options_general_product_data', 'naturally_add_badge_checkbox_to_products' );
		function naturally_add_badge_checkbox_to_products()
		{
			woocommerce_wp_select(
				array(
					'id' => 'naturally_badge',
					'label' => esc_html__( 'Naturally Badge?', 'naturally' ),
					'options' => array(
						'' => 'Select a badge',
						'new' => esc_html__( 'New', 'naturally' ),
						'hot' => esc_html__( 'Hot', 'naturally' ),
						'best' => esc_html__( 'Best', 'naturally' ),
						'featured' => esc_html__( 'Featured', 'naturally' ),
						'free' => esc_html__( 'Free', 'naturally' ),
						'custom' => esc_html__( 'Custom', 'naturally' ),
					),
					'desc_tip'    => false,
				)
			);
			woocommerce_wp_text_input(
				array(
					'id'          => 'naturally_custom_badge',
					'label'       => esc_html__( 'Custom Badge Label', 'naturally' ),
					'description' => esc_html__( 'Add your custom badge label here', 'naturally' ),
				)
			);
			woocommerce_wp_select(
				array(
					'id' => 'naturally_badge_color',
					'label' => esc_html__( 'Naturally Badge Color?', 'naturally' ),
					'options' => array(
						'' => 'Select a badge',
						'is-primary' => esc_html__( 'primary', 'naturally' ),
						'is-secondary' => esc_html__( 'secondary', 'naturally' ),
						'is-black' => esc_html__( 'black', 'naturally' ),
						'is-grey' => esc_html__( 'grey', 'naturally' ),
						'is-white' => esc_html__( 'white', 'naturally' ),
						'is-blue' => esc_html__( 'blue', 'naturally' ),
						'is-green' => esc_html__( 'green', 'naturally' ),
						'is-orange' => esc_html__( 'orange', 'naturally' ),
						'is-red' => esc_html__( 'red', 'naturally' ),
						'is-purple' => esc_html__( 'purple', 'naturally' ),
						'is-blue-light' => esc_html__( 'blue-light', 'naturally' ),
						'is-green-light' => esc_html__( 'green-light', 'naturally' ),
						'is-orange-light' => esc_html__( 'orange-light', 'naturally' ),
						'is-red-light' => esc_html__( 'red-light', 'naturally' ),
						'is-purple-light' => esc_html__( 'purple-light', 'naturally' ),
					),
					'desc_tip'    => false,
				)
			);
		}
	}

	/*********************************************************
	## 2. SAVE CHECKBOX VIA CUSTOM FIELD
	**********************************************************/

	if ( ! function_exists( 'naturally_save_badge_checkbox_to_post_meta' ) ) {

		add_action( 'save_post', 'naturally_save_badge_checkbox_to_post_meta' );
		function naturally_save_badge_checkbox_to_post_meta( $product_id )
		{
		    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
				return;
			}
		    if ( isset( $_POST['naturally_badge'] ) ) {
		            update_post_meta( $product_id, 'naturally_badge', $_POST['naturally_badge'] );
		    } else {
				delete_post_meta( $product_id, 'naturally_badge' );
			}
		    if ( isset( $_POST['naturally_badge_color'] ) ) {
		            update_post_meta( $product_id, 'naturally_badge_color', $_POST['naturally_badge_color'] );
		    } else {
				delete_post_meta( $product_id, 'naturally_badge_color' );
			}
		    if ( isset( $_POST['naturally_custom_badge'] ) ) {
		            update_post_meta( $product_id, 'naturally_custom_badge', $_POST['naturally_custom_badge'] );
		    } else {
				delete_post_meta( $product_id, 'naturally_custom_badge' );
			}
		}
	}

	/*************************************************
	## WOO CART AJAX
	*************************************************/

	if ( ! function_exists( 'naturally_header_woo_myaccount' ) ) {
		add_action( 'naturally_header_woo_myaccount_action', 'naturally_header_woo_myaccount', 10 );
		function naturally_header_woo_myaccount()
		{
			if ( '0' != naturally_settings('header_account_visibility', '1')  ) {
				$currentUser = wp_get_current_user(); ?>
				<div class="header_menu_item">
					<a class="header_menu_link" href="<?php echo get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ); ?>">
						<span class="header_menu_link_icon icon is-avatar"></span>
						<span class="header_menu_link_text"><?php echo esc_html_e('My Account', 'naturally'); ?></span>
						<span class="screen-reader-text"><?php echo sprintf( esc_html__( 'Hi, %s', 'naturally' ), $currentUser->display_name ); ?></span>
					</a>
				</div>
			<?php
			}
		}
	}

	if ( ! function_exists( 'naturally_header_mini_cart' ) ) {
		add_action( 'naturally_header_mini_cart_action', 'naturally_header_mini_cart', 10 );
		function naturally_header_mini_cart()
		{
			global $woocommerce;
			?>
			<div class="header_cart">
				<div class="header_cart_label">
					<span class="header_cart_label_icon icon is-bag"></span>
					<span class="header_cart_label_text"><?php printf( '%s', $woocommerce->cart->get_cart_subtotal() ); ?> / <?php echo sprintf(_n('%d item', '%d items', WC()->cart->cart_contents_count, 'naturally'), WC()->cart->cart_contents_count);?></span>
				</div>
				<?php get_template_part('woocommerce/header', 'minicart'); ?>
			</div>
			<?php
		}
	}

	if ( ! function_exists( 'naturally_header_add_to_cart_fragment' ) ) {
		add_filter('add_to_cart_fragments', 'naturally_header_add_to_cart_fragment');
		function naturally_header_add_to_cart_fragment( $fragments )
		{
			global $woocommerce;
			ob_start(); ?>
			<span class="header_cart_label_text"><?php printf( '%s', $woocommerce->cart->get_cart_subtotal() ); ?> / <?php echo sprintf(_n('%d item', '%d items', WC()->cart->cart_contents_count, 'naturally'), WC()->cart->cart_contents_count);?></span>
			<?php
			$fragments['span.header_cart_label_text'] = ob_get_clean();
			return $fragments;
		}
	}

	if ( ! function_exists( 'naturally_header_add_to_cart_content' ) ) {
		add_filter('woocommerce_add_to_cart_fragments', 'naturally_header_add_to_cart_content');
		function naturally_header_add_to_cart_content( $fragments )
		{
			ob_start();
			get_template_part('woocommerce/header', 'minicart');
			$fragments['div.header_cart_detail'] = ob_get_clean();
			return $fragments;
		}
	}

	/*************************************************
	## WOO SHOP PER PAGE VIA SELECT BOX
	*************************************************/

	if ( !function_exists( 'naturally_post_perpage_selectbox' ) ) {
		add_action( 'woocommerce_before_shop_loop', 'naturally_post_perpage_selectbox', 35 );
		function naturally_post_perpage_selectbox()
		{
			if ( is_shop() ) {
				$p_pp = naturally_settings('shop_perpage','12');
				$per_page = filter_input(INPUT_GET, 'perpage', FILTER_SANITIZE_NUMBER_INT);
				$total_products = count( get_posts( array('post_type' => 'product', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) );

			    //$orderby = array();
				for ($i=$p_pp; $i < $total_products; $i++) {
					$orderby_options[$i] = $i;
					$i=$i+5;
				}
				$orderby_options[$total_products] = $total_products;
				?>
				<div class="shop-header_select">
					<span><?php esc_html_e('Show','naturally'); ?></span>
					<select class="form_control_select" name="showLimit" onchange="if (this.value) window.location.href=this.value">
						<?php
						foreach( $orderby_options as $value => $label ) { ?>
							<option <?php selected( $per_page, $value ); ?> value="?perpage=<?php echo esc_attr($value);?>"><?php echo esc_html($label);?></option>
						<?php } ?>
					</select>
				</div>
				<?php
			}
		}
	}

	if ( !function_exists( 'naturally_pre_get_products_query' ) ) {
		add_action( 'pre_get_posts', 'naturally_pre_get_products_query' );
		function naturally_pre_get_products_query( $query )
		{

		    $per_page = filter_input(INPUT_GET, 'perpage', FILTER_SANITIZE_NUMBER_INT);
		    if( $query->is_main_query() && !is_admin() && is_post_type_archive( 'product' ) ) {
			    if( $per_page == null ) {
			        $query->set( 'posts_per_page', naturally_settings('shop_perpage','12') );
			    } else {
					$query->set( 'posts_per_page', $per_page );
				}
			}
		}
	}


	/*************************************************
 	## CHANGE NUMBER OF RELATED PRODUCTS OUTPUT
 	*************************************************/

	if ( !function_exists( 'naturally_woo_related_products_limit' ) ) {

		add_filter( 'woocommerce_output_related_products_args', 'naturally_woo_related_products_limit', 20 );
		function naturally_woo_related_products_limit( $args ) {
			$args['posts_per_page'] = naturally_settings('single_shop_related_count', '6'); // 4 related products // arranged in 2 columns
			return $args;
		}
	}


	/*************************************************
	## REGISTER SIDEBAR FOR WOOCOMMERCE
	*************************************************/

	if ( !function_exists( 'naturally_woo_widgets_init' ) ) {

		function naturally_woo_widgets_init()
		{
			//Shop page sidebar
			register_sidebar( array(
				'name' => esc_html__( 'Shop Page Sidebar', 'naturally' ),
				'id' => 'shop-page-sidebar',
				'description' => esc_html__( 'These widgets for the Shop page.','naturally' ),
				'before_widget' => '<div class="nt-sidebar-inner-widget nt-shop-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h4 class="nt-sidebar-widget-title title">',
				'after_title' => '</h4>'
			) );
		}
		add_action( 'widgets_init', 'naturally_woo_widgets_init' );
	}


	/*************************************************
	## ADD SECTION TO THEME OPTIONS FOR WOOCOMMERCE
	*************************************************/

	if ( class_exists( 'Redux' ) ) {

		if ( ! function_exists( 'naturally_dynamic_section' ) ) {

			function naturally_dynamic_section( $sections )
			{
				global $naturally_pre;

				/*************************************************
				## SHOP PAGE SECTION
				*************************************************/
			   $sections[] = array(
				   'title' => esc_html__('Shop Page', 'naturally'),
				   'id' => 'shopsection',
				   'icon' => 'el el-shopping-cart-sign',
			   );
				$sections[] = array(
					'title' => esc_html__( 'Shop Page Layout', 'naturally' ),
					'id' => 'shoplayoutsection',
					'subsection'=> true,
					'icon' => 'el el-website',
					'fields'	=> array(
						array(
							'title' => esc_html__( 'Shop Page Layout', 'naturally' ),
							'subtitle' => esc_html__( 'Choose the shop page layout.', 'naturally' ),
							'id' => 'shop_layout',
							'type' => 'image_select',
							'options' => array(
								'left-sidebar' => array(
									'alt' => 'Left Sidebar',
									'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
								),
								'full-width' => array(
									'alt' => 'Full Width',
									'img' => ReduxFramework::$_url . 'assets/img/1col.png'
								),
								'right-sidebar' => array(
									'alt' => 'Right Sidebar',
									'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
								),
							),
							'default' => 'full-width'
						),
						array(
							'title' => esc_html__('Shop Post Column', 'naturally'),
							'subtitle' => esc_html__('You can control post column with this option.', 'naturally'),
							'id' => 'shop_column',
							'type' => 'slider',
							'default' => 3,
							'min' => 2,
							'step' => 1,
							'max' => 4,
							'display_value' => 'text',
						),
						array(
							'title' => esc_html__('Shop Post Count', 'naturally'),
							'subtitle' => esc_html__('You can control show post count with this option.', 'naturally'),
							'id' => 'shop_perpage',
							'type' => 'slider',
							'default' => 12,
							'min' => 1,
							'step' => 1,
							'max' => count( get_posts( array('post_type' => 'product', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) ),
							'display_value' => 'text'
						),
						array(
							'title' => esc_html__('Shop Page Subtitle', 'naturally'),
							'subtitle' => esc_html__('Add your shop page sub title here.', 'naturally'),
							'id' => 'shop_page_subtitle',
							'type' => 'text',
							'default' => '',
							'required' => array( 'single_shop_related_visibility', '=', '1' )
						),
					)
				);

				/*************************************************
			    ## SINGLE PAGE SECTION
			    *************************************************/
	 			$sections[] = array(
					'title' => esc_html__('Shop Single Page', 'naturally'),
					'id' => 'singleshopsection',
					'icon' => 'el el-shopping-cart-sign',
	 			);
				$sections[] = array(
					'title' => esc_html__('General', 'naturally'),
					'id' => 'singleshopgeneral',
					'subsection' => true,
					'icon' => 'el el-brush',
					'fields' => array(
						array(
			                'title' => esc_html__('Single Related', 'naturally'),
			                'subtitle' => esc_html__('If enabled, shows related post at single page.', 'naturally'),
			                'id' => 'single_shop_related_visibility',
			                'type' => 'switch',
			                'default' => true
			            ),
						array(
							'title' => esc_html__('Single Related Title', 'naturally'),
							'subtitle' => esc_html__('Add your single shop page related section title here.', 'naturally'),
							'id' => 'single_shop_related_title',
							'type' => 'textarea',
							'default' => '',
							'required' => array( 'single_shop_related_visibility', '=', '1' )
						),
						array(
							'title' => esc_html__('Related Post Count', 'naturally'),
							'subtitle' => esc_html__('You can control show related post count with this option.', 'naturally'),
							'id' => 'single_shop_related_count',
							'type' => 'slider',
							'default' => 6,
							'min' => 1,
							'step' => 1,
							'max' => 24,
							'display_value' => 'text',
							'required' => array( 'single_shop_related_visibility', '=', '1' )
						)
					)
				);
				return $sections;
	    	}
	        add_filter('redux/options/'.$naturally_pre.'/sections', 'naturally_dynamic_section');
		}
	}


	/************************************************************
	## ADD THEME CSS SETTINGS TO WOOCOMMERCE AND WP INLINE STYLE
	*************************************************************/

	if ( !function_exists( 'naturally_woo_theme_css_options' ) ) {
	  function naturally_woo_theme_css_options() {

		/* CSS to output */

		 $theCSS = '';

			$shop_theme_color = naturally_settings('theme_color');

			// css color
			$theCSS .= '';

			/* Add CSS to naturally-custom-style.css */
			wp_register_style( 'naturally-woo-style', false );
			wp_enqueue_style( 'naturally-woo-style' );
			wp_add_inline_style( 'naturally-woo-style', $theCSS );

		}
		add_action( 'wp_enqueue_scripts', 'naturally_woo_theme_css_options' );
	}

}// end if class_exists (WooCommerce)
